@@ -58,7 +58,7 @@ class MPlayerPlayer(PlayerBase.PlayerBase):
             self.stopSong()
         if self.isRunning:
             self.quitRunning()
-            self.__mplayer.join(1)
+            self.__mplayer.join(0.5)
 
     def quitRunning(self):
         """ Signal MPlayer to quit running. """
