@@ -192,17 +192,18 @@ class PlayerThread(Thread):
             # Signal to play the set song
             # TODO use the play signal
             if command == self.__commandPlay:
-                self.__blIsStarting = True
-                signal = self.__playerCommand + " " + \
-                    self.__PlayerCommandArguments + self.__songFilePath
-                print "Player Thread Running Signal Play: %s" % signal
-                self.__ppnPlayer = Popen(signal, shell=True, \
-                    stdin=PIPE, stdout=PIPE, stderr=PIPE)
-                if self.__ppnPlayer.poll() is not None:
-                    raise OSError("Failed to open media file!")
-                self.__blIsPlaying = True
-                self.__blIsSongEnded = False
-                self.__blIsStarting = False
+                if not self.__blIsPlaying and not self.__blIsPaused:
+                    self.__blIsStarting = True
+                    signal = self.__playerCommand + " " + \
+                        self.__PlayerCommandArguments + self.__songFilePath
+                    print "Player Thread Running Signal Play: %s" % signal
+                    self.__ppnPlayer = Popen(signal, shell=True, \
+                        stdin=PIPE, stdout=PIPE, stderr=PIPE)
+                    if self.__ppnPlayer.poll() is not None:
+                        raise OSError("Failed to open media file!")
+                    self.__blIsPlaying = True
+                    self.__blIsSongEnded = False
+                    self.__blIsStarting = False
                 print "Player Thread End Of Signal Play"
 
             # Signal to stop the song
@@ -412,7 +413,15 @@ class PlayerThread(Thread):
         """
         # TODO check to ensure the file exists.
         if not filePath:
-            print "PlayerThread.play(self, filePath, volume): Empty filePath"
+            print "PlayerThread.play(): Empty filePath"
+            return False
+        elif not os.access(filePath, os.F_OK):
+            print "PlayerThread.play(): File not found: %s " % \
+                self.__songFilePath
+            return False
+        elif not os.access(filePath, os.R_OK):
+            print "PlayerThread.play(): File doesn't have read access: %s " % \
+                self.__songFilePath
             return False
         elif not self.__blIsPlaying and not self.__blIsPaused:
             self.__songFilePath = " \"" + filePath + "\""
