@@ -38,6 +38,8 @@ class PlayListWindow(wx.Panel):
     __BUTTON_MOVEMENT_WIDTH = 45
     # The height to set the movement buttons at.
     __BUTTON_MOVEMENT_HEIGHT = 45
+    # Song index tracker for only within playFirstSong()
+    __songIndex = -1
 
     """
      EVENT ID
@@ -158,13 +160,21 @@ class PlayListWindow(wx.Panel):
         """ Play the first song in the play-list.
 
          Play the first song in the play-list, and then remove it from the
-           play-list.
+           play-list. When the song is not removed from the play-list it
+           will track the play-list location.
          boolean removeSong: indicates if the selected song should be removed
            after the method returns.
          return MediaSong: the first song in the play-list.
         """
-        self.__lstBxPlayList.SetSelection(0)
-        return self.playSelectedSong(removeSong)
+        if removeSong:
+            self.__lstBxPlayList.SetSelection(0)
+            return self.playSelectedSong(True)
+        else:
+            self.__songIndex += 1
+            if self.__songIndex == len(self.__playList):
+                self.__songIndex = 0
+            self.__lstBxPlayList.SetSelection(self.__songIndex)
+            return self.playSelectedSong(False)
 
     def playRandomSong(self, removeSong=True):
         """ Play a random song from the play-list.
